@@ -21,20 +21,18 @@
 #   - test for errors
 
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
+from io import StringIO
 
-from commons import BaseTestCase
+import commons
 from ovirt_setup_lib.hostname import Hostname
 
 
-class HostnameTestCase(BaseTestCase):
+class HostnameTestCase(commons.BaseTestCase):
 
     def setUp(self):
         self.mock_otopi()
         self.apply_patch()
+        self.Plugin.context.currentStage = 0
         self.Plugin.command.enum.return_value = ['dig', 'ip']
         self.hostname = Hostname(self.Plugin)
 
@@ -42,7 +40,7 @@ class HostnameTestCase(BaseTestCase):
         self.hostname.command.get.return_value = '/bin/ip'
         self.hostname.execute.return_value = (
             0,
-            StringIO('''\
+            StringIO(u'''\
 1: lo: <LOOPBACK,UP,LOWER_UP> mtu 65536 qdisc noqueue state UNKNOWN group \
 default
     link/loopback 00:00:00:00:00:00 brd 00:00:00:00:00:00
@@ -60,7 +58,7 @@ dynamic
        valid_lft 2591873sec preferred_lft 604673sec
     inet6 fe80::56ee:75ff:fe5c:6daa/64 scope link
        valid_lft forever preferred_lft forever'''),
-            StringIO(''),
+            StringIO(u''),
         )
 
         addr = self.hostname.getLocalAddresses()
@@ -85,7 +83,7 @@ dynamic
         self.hostname.command.get.return_value = '/bin/ip'
         self.hostname.execute.return_value = (
             0,
-            StringIO('''\
+            StringIO(u'''\
 1: lo: <LOOPBACK,UP,LOWER_UP> mtu 65536 qdisc noqueue state UNKNOWN group \
 default
     link/loopback 00:00:00:00:00:00 brd 00:00:00:00:00:00
@@ -103,7 +101,7 @@ dynamic
        valid_lft 2591873sec preferred_lft 604673sec
     inet6 fe80::56ee:75ff:fe5c:6daa/64 scope link
        valid_lft forever preferred_lft forever'''),
-            StringIO(''),
+            StringIO(u''),
         )
 
         addr = self.hostname.getLocalAddresses(exclude_loopback=True)
@@ -127,7 +125,7 @@ dynamic
         self.hostname.command.get.return_value = '/bin/ip'
         self.hostname.execute.return_value = (
             0,
-            StringIO('''\
+            StringIO(u'''\
 5: my-bond: <BROADCAST,MULTICAST,MASTER,UP,LOWER_UP> mtu 1500 qdisc noqueue \
 state UP qlen 1000
     link/ether 00:14:5e:dd:05:55 brd ff:ff:ff:ff:ff:ff
@@ -138,7 +136,7 @@ dynamic
        valid_lft 2591821sec preferred_lft 604621sec
     inet6 fe80::b925:96f4:3a25:af8/64 scope link
        valid_lft forever preferred_lft forever'''),
-            StringIO(''),
+            StringIO(u''),
         )
 
         addr = self.hostname.getLocalAddresses(
@@ -164,7 +162,7 @@ dynamic
         self.hostname.command.get.return_value = '/usr/bin/dig'
         self.hostname.execute.return_value = (
             0,
-            StringIO('''
+            StringIO(u'''
 ; <<>> DiG 9.10.2-P4 <<>> -x 8.8.8.8
 ;; global options: +cmd
 ;; Got answer:
@@ -185,7 +183,7 @@ dynamic
 ;; MSG SIZE  rcvd: 93
 
 '''),
-            StringIO(''),
+            StringIO(u''),
         )
 
         names = self.hostname._dig_reverse_lookup('8.8.8.8')
@@ -202,7 +200,7 @@ dynamic
         self.hostname.command.get.return_value = '/usr/bin/dig'
         self.hostname.execute.return_value = (
             0,
-            StringIO('''
+            StringIO(u'''
 
 ; <<>> DiG 9.10.2-P4 <<>> ovirt.org
 ;; global options: +cmd
@@ -224,7 +222,7 @@ ovirt.org.              3600    IN      A       173.255.252.138
 ;; MSG SIZE  rcvd: 54
 
 '''),
-            StringIO(''),
+            StringIO(u''),
         )
 
         resolved = self.hostname.isResolvedByDNS('ovirt.org')
